==> pypy_1.9+dfsg.orig.tar.xz: pypy-1.9.orig/lib_pypy/_pypy_irc_topic.py <==
"""eclguba: flagnk naq frznagvpf bs clguba, fcrrq bs p, erfgevpgvbaf bs wnin naq pbzcvyre reebe zrffntrf nf crargenoyr nf ZHZCF
pglcrf unf n fcva bs 1/3
' ' vf n fcnpr gbb
Clguba 2.k rfg cerfdhr zbeg, ivir Clguba!
Clguba 2.k vf abg qrnq
Riregvzr fbzrbar nethrf jvgu "Fznyygnyx unf nyjnlf qbar K", vg vf  nyjnlf n tbbq uvag gung fbzrguvat arrqf gb or punatrq snfg. - Znephf Qraxre
Rirel gvzr fbzrbar nethrf jvgu "Fznyygnyx unf nyjnlf qbar K", vg vf nyjnlf n tbbq uvag gung fbzrguvat arrqf gb or punatrq snfg. - Znephf Qraxre
__kkk__ naq __ekkk__ if bcrengvba fybgf: cnegvpyr dhnaghz fhcrecbfvgvba xvaq bs sha
ClCl vf na rkpvgvat grpuabybtl gung yrgf lbh gb jevgr snfg, cbegnoyr, zhygv-cyngsbez vagrecergref jvgu yrff rssbeg
Nezva: "Cebybt vf n zrff.", PS: "Ab, vg'f irel pbby!", Nezva: "Vfa'g guvf jung V fnvq?"
ClCl vf yvxr nofheq gurngre
jr unir ab nagv-vzcbffvoyr fgvpx gung znxrf fher gung nyy lbhe cebtenzf unyg
clcl vf n enpr orgjrra crbcyr funivat lnxf naq gur havirefr cebqhpvat zber orneqrq lnxf. Fb sne, gur havirefr vf jvaavat
Nyy ceboyrzf va pbzchgre fpvrapr pna or fbyirq ol nabgure yriry bs vaqverpgvba. --Ohgyre Ynzcfba
jr ner zbivat gbjneqf n ernyyl cngpu-serr nffrzoyre jbeyq (nezva)
<nevtngb> svwny: V'z fher gurer vf gbaf bs hafcrpvsvrq pbagrkg vasbezngvba gung V fubhyq vqrnyyl nyfb or njner bs
<pnzv> V yvxr jbexva jvgu clcl, vg'f yvxr fcrnxvat puvarfr
<nevtngb> lrf ohg gurer vf abg zhpu frafr vs V rkcynva nyy nobhg gbqnl'f terngrfg vqrn vs gbzbeebj vg'f pbzcyrgryl bhgqngrq
<psobym> gur wvg'f fcrrq vf zrnfherq va zo ugzy/frp naq gur qrirybczrag fcrrq vf zrnfherq va oenapurf/qnl
<psobym> gur wvg'f fcrrq vf zrnfherq va bar bire zo ugzy/frp naq gur qrirybczrag fcrrq vf zrnfherq va oenapurf/qnl
gur mra nggvghqr gb cebtenzzvat: erqhpvat gur bbcfrf va lbhe yvsr
clcl vf gur ahpyrne shfvba bs cebtenzzvat ynathntr vzcyrzragngvba (crqebavf)
Gur rkgen oynax yvarf gung clcl cevagf haqre jvaqbjf pbzr sebz qvfghgvyf gung qbrf abg svaq Ivfhny Fghqvb 6
ClCl 1.1.0orgn eryrnfrq: uggc://pbqrfcrnx.arg/clcl/qvfg/clcl/qbp/eryrnfr-1.1.0.ugzy
"gurer fubhyq or bar naq bayl bar boivbhf jnl gb qb vg". ClCl inevnag: "gurer pna or A unys-ohttl jnlf gb qb vg"
1.1 svany eryrnfrq: uggc://pbqrfcrnx.arg/clcl/qvfg/clcl/qbp/eryrnfr-1.1.0.ugzy
<svwny> nzq64 naq ccp ner bayl ninvynoyr va ragrecevfr irefvba
Vf gurer n clcl gvzr? - vs lbh pna srry vg (?) gura gurer vf
<nevtngb> ab, abezny jbex vf fhpu zhpu yrff gvevat guna inpngvbaf
<nevtngb> ab, abezny jbex vf fb zhpu yrff gvevat guna inpngvbaf
-SVEFG gurl vtaber lbh, gura gurl ynhtu ng lbh, gura gurl svtug lbh, gura lbh jva.-
vg'f Fhaqnl, znlor
vg'f Fhaqnl, ntnva
"3 + 3 = 8" - Nagb va gur WVG gnyx
RPBBC vf unccravat
RPBBC vf svavfurq
cflpb rngf bar oenva cre vapu bs cebterff
"Fbzrjurer vafvqr gur ynetr yhzorevat oybo bs ClCl gurer vf na ryrtnag pber gelvat gb trg bhg." - psobym
<nevtngb> gur NV fgngr vf vaqrrq pybfr
gur yytencu onpxraq vf n PCH gbb
jung ner n srj snyfr cbfvgvirf orgjrra sevraqf
abg vaperqvoyl ryrtnag, ohg pbhyq jbex
Jura lbhe unzzre vf P++, rirelguvat ortvaf gb ybbx yvxr n guhzo.
Gurersber, fcrpvsvp vasbezngvba, V jnf va na vqrny pbagrkg, V unq gb ernyvmr gur snvgu
ClCl qrirybczrag: gur neg bs jnvgvat
ubj gb pbafgehpg gur oynpxubyr vagrecergre: jr erhfr gur genpvat bar, nqq ybgf bs vsf naq cenl
clcl vf zber fgnoyr guna qrovna
gur jbeyq qbrfa'g jnag hf gb xabj
guvatf jbexrq avpryl gvyy gbqnl whfg ol punapr
enaqbz ohtf va enaqbz (abg n shaal wbxr)
ab enaqbz ohtf va enaqbz, nsgre nyy
vg'f ornhgvshy: irel erpgnathyne naq lryybj
V jnag n terra gevnathyne lryybj cbal
Vf vg n pnpghf oht be ceboyrz jvgu zl jne?
vg'f qhpg gncr nyy gur jnl qbja ohg abg gur jnl hc
"ribyhgrq" = havba bs "ribyirq" naq "pbaibyhgrq"
vg'f abafrafr nyy gur jnl qbja, naq nyfb nyy gur jnl hc
vg'f abg pbzcyrgryl fnar, ohg gung unf arire fgbccrq hf
gur shgher unf whfg ortha
jung jr npuvrirq gbqnl: jr qvfphffrq gur cbalarff bs gvzr-znpuvarf
Gur gvzr qrpernfrf!
"Jul qb jr raq hc va n aba pbzzba pnfr va gur pbzzba pnfr?" (svwny)
"nu, whfg va gvzr qbphzragngvba" (__nc__)
ClCl vf abg n erny IZ: ab frtsnhyg unaqyref gb qb gur ener pnfrf
lbh pna'g unir obgu pbairavrapr naq fcrrq
fyvccref urvtug pna or zrnfherq va k86 ertvfgref
clcl vf n enpr orgjrra gur vaqhfgel gelvat gb ohvyq znpuvarf jvgu zber naq zber erfbheprf, naq gur clcl qrirybcref gelvat gb rng nyy bs gurz. Fb sne, gur jvaare vf fgvyy hapyrne
"znl pbagnva ahgf naq/be lbhat cbvagref"
vg'f nyy irel fvzcyr, yvxr gur ubyvqnlf
unccl ClCl'f lrne 2010!
fnzhryr fnlf gung jr ybfg n enmbe. fb jr pna'g funir lnxf
"yrg'f abg or bofpher, hayrff jr ernyyl arrq gb"
<nevtngb> (abg guernq-fnsr, ohg jryy, abguvat vf)
clcl unf znal ceboyrzf, ohg rnpu bar unf znal fbyhgvbaf
whfg nabgure vgrz (1.333...) ba bhe erny-ahzorerq gbqb yvfg
ClCl vf Fuveg Bevtnzv erfrnepu
<svwny> nafjrevat n dhrfgvba: "ab -- sbe ng yrnfg bar cbffvoyr vagrecergngvba bs lbhe fragrapr"
eryrnfr 1.2 hcpbzvat
ClCl 1.2 eryrnfrq - uggc://clcl.bet/
AB IPF QVFPHFFVBAF
EClguba vf n svar pnzry unve oehfu
ClCl vf n npghnyyl n ivfhnyvmngvba cebwrpg, jr whfg ohvyq vagrecergref gb unir vagrerfgvat qngn gb ivfhnyvmr
clcl vf yvxr fnhfntrf
naq abj sbe fbzrguvat pbzcyrgryl qvssrerag
n 10gu bs sberire vf 1u45
pbeerpg pbqr qbrfag arrq nal grfgf <qhpx>
cbfgfgehpghenyvfz rgp.
clcl UVG trarengbe
gur arj clcl fcbeg vf gb cnff clcl ohtf nf pclguba ohtf
jr unir zhpu zber vagrecergref guna hfref
ClCl 1.3 njnvgvat eryrnfr
ClCl 1.3 eryrnfrq
vg frrzf gb zr gung bapr lbh frggyr ba na rkrphgvba / bowrpg zbqry naq / be olgrpbqr sbezng, lbh'ir nyernql qrpvqrq jung ynathntrf (jurer gur 'f' frrzf fhcresyhbhf) fhccbeg vf tbvat gb or svefg pynff sbe
"Nyy ceboyrzf va ClCl pna or fbyirq ol nabgure yriry bs vagrecergngvba"
ClCl 1.3 eryrnfrq (jvaqbjf ovanevrf vapyhqrq)
jul qvq lbh thlf unir gb znxr gur ohvygva sbeghar zber vagrerfgvat guna npghny jbex? v whfg pngpurq zlfrys erfgnegvat clcl 20 gvzrf
"jr hfrq gb unir n zrff jvgu na bofpher vagresnpr, abj jr unir zrff urer naq bofpher vagresnpr gurer. cebterff" crqebavf ba n clcl fcevag
"phcf bs pbssrr ner yvxr nanybtvrf va gung V'z znxvat bar evtug abj"
"vg'f nyjnlf hc gb hf, va n jnl be gur bgure"
ClCl vf infg, naq pbagnvaf zhygvghqrf
qravny vf eneryl n tbbq qrohttvat grpuavdhr
"Yrg'f tb." - "Jr pna'g" - "Jul abg?" - "Jr'er jnvgvat sbe n Genafyngvba." - (qrfcnvevatyl) "Nu!"
'gung'f qrsvavgryl n pnfr bs "hu????"'
va gurbel gurer vf gur Ybbc, va cenpgvpr gurer ner oevqtrf
gur uneqqevir - pbafgnag qngn cvytevzntr
ClCl vf n gbby gb xrrc bgurejvfr qnatrebhf zvaqf fnsryl bpphcvrq.
jr ner n trareny senzrjbex ohvyg ba pbafvfgrag nccyvpngvba bs nqubp-arff
gur jnl gb nibvq n jbexnebhaq vf gb vagebqhpr n fgebatre jbexnebhaq fbzrjurer ryfr
pnyyvat gur genafyngvba gbby punva n 'fpevcg' vf xvaq bs bssrafvir
ehaavat clcl-p genafyngr.cl vf n ovg yvxr jngpuvat n guevyyre zbivr, vg pbhyq pbafhzr nyy gur zrzbel ng nal gvzr
ehaavat clcl-p genafyngr.cl vf n ovg yvxr jngpuvat n guevyyre zbivr, vg pbhyq qvr ng nal gvzr orpnhfr bs gur 32-ovg 4TO yvzvg bs ENZ
Qh jvefg rora tranh qnf reervpura, jbena xrvare tynhog
vs fjvgmreynaq jrer jurer terrpr vf (ba vfynaqf) jbhyq gurl nyy or pbaarpgrq ol oevqtrf?
genafyngvat clcl jvgu pclguba vf fbbbbbb fybj
ClCl 1.4 eryrnfrq!
Jr ner abg urebrf, whfg irel cngvrag.
QBAR zrnaf vg'f qbar
jul gurer vf ab "ClCl 1.4 eryrnfrq" va gbcvp nal zber?
fabj! fabj!
svanyyl, zrephevny zvtengvba vf unccravat!
Gur zvtengvba gb zrephevny vf pbzcyrgrq! uggc://ovgohpxrg.bet/clcl/clcl
fabj! fabj! (gre)
unccl arj lrne
naq anaanaw gb lbh nf jryy
Frrvat nf gur ynjf bs culfvpf ner ntnvafg lbh, lbh unir gb pnershyyl pbafvqre lbhe fpbcr fb gung lbhe tbnyf ner ernfbanoyr.
nf hfhny va clcl, gur fbyhgvba nccrnef pbzcyrgryl qvfcebcbegvbangr gb gur ceboyrz naq vafgrnq jr'yy tb sbe n pbzcyrgryl qvssrerag fvzcyre nccebnpu gb gur bevtvany ceboyrz
fabj, fabj!
va clcl lbh ner nyjnlf ng gur jebat yriry, va bar jnl be gur bgure
jryy, vg'f jebat ohg abg fb "irel jebat" nf vg ybbxrq
<svwny> V ybir clcl
ynmvarff vzcngvrapr naq uhoevf
fabj, fabj
EClguba: guvatf lbh jbhyqa'g qb va Clguba, naq pna'g qb va P.
vg vf gur rkcrpgrq orunivbe, rkprcg jura lbh qba'g rkcrpg vg
erqrsvavat lryybj frrzf yvxr n orggre vqrn
"gung'f ubjrire whfg ratvarrevat" (svwny)
"[vg] whfg fubjf ntnva gung eclguba vf bofpher" (psobym)
"naljnl, clguba vf n infg ynathntr" (svwny)
bhg-bs-yvr-thneqf
"gurer ner qnlf ba juvpu lbh ybbx nebhaq naq abguvat fubhyq unir rire jbexrq" (svwny)
clcl vf n orggre xvaq bs sbbyvfuarff - ynp
ehaavat grfgf vf rffragvny sbe qrirybcvat clcl -- hu? qvq V oernx gur grfg? (svwny)
V'ir tbg guvf sybbe jnk gung'f nyfb n TERNG qrffreg gbccvat!!
rknexha: "gur cneg gung V gubhtug jnf tbvat gb or uneq jnf gevivny, fb abj V whfg unir guvf cneg gung V qvqa'g rira guvax bs gung vf uneq"
V fhccbfr jr pna yvir jvgu gur bofphevgl, nf ybat nf gurer vf n pbzzrag znxvat vg yvtugre
V nz n ovt oryvrire va ernfbaf. ohg gur nccnerag xvaq ner zl snibevgr.
clcl: trg n WVG sbe serr (jryy gur svefg qnl lbh jba'g znantr naq vg jvyy or irel sehfgengvat)
<Nyrk_Tnlabe> thgjbegu: bu, jr fubhyq znxr gur WVG zntvpnyyl orggre, jvgu qrpbengbef naq fghss
vg'f n pbzcyrgr unpx, ohg n irel zvavzny bar (nevtngb)
svefg gurl ynhtu ng lbh, gura gurl vtaber lbh, gura gurl svtug lbh, gura lbh jva
ClCl vf snzvyl sevraqyl
jr yvxr pbzcynvagf
gbqnl jr'er snfgre guna lrfgreqnl (hfhnyyl)
ClCl naq PClguba: gurl ner zbegny rarzvrf vagrag ba xvyyvat rnpu bgure
nethnoyl, rirelguvat vf n avpur
clcl unf ynlref yvxr bavbaf: crryvat gurz onpx jvyy znxr lbh pel
EClguba zntvpnyyl znxrf lbh evpu naq snzbhf (fnlf fb ba gur gva)
Vf evtbobg nebhaq jura gur havirefr prnfrf gb rkvfg?
ClCl vf gbb pbby sbe dhrelfgevatf.
< nevtngb> gura jung bpphef? < svwny> tbbq fghss V oryvrir
ClCl 1.6 eryrnfrq!
<psobym> jurer ner gur grfgf?
uggc://gjvgcvp.pbz/52nr8s
N enaqbz dhbgr
Nyy rkprcgoybpxf frrz fnar.
N cvax tyvggrel ebgngvat ynzoqn
"vg'f yvxryl grzcbenel hagvy sberire" nevtb
"""

def some_topic():
    import time
    lines = __doc__.splitlines()
    return lines[int(time.time()) % len(lines)].decode('rot13')

==> pypy_2.0.2+dfsg.orig.tar.xz: pypy-2.0.2.orig/lib_pypy/_pypy_irc_topic.py <==
"""eclguba: flagnk naq frznagvpf bs clguba, fcrrq bs p, erfgevpgvbaf bs wnin naq pbzcvyre reebe zrffntrf nf crargenoyr nf ZHZCF
pglcrf unf n fcva bs 1/3
' ' vf n fcnpr gbb
Clguba 2.k rfg cerfdhr zbeg, ivir Clguba!
Clguba 2.k vf abg qrnq
Riregvzr fbzrbar nethrf jvgu "Fznyygnyx unf nyjnlf qbar K", vg vf  nyjnlf n tbbq uvag gung fbzrguvat arrqf gb or punatrq snfg. - Znephf Qraxre
Rirel gvzr fbzrbar nethrf jvgu "Fznyygnyx unf nyjnlf qbar K", vg vf nyjnlf n tbbq uvag gung fbzrguvat arrqf gb or punatrq snfg. - Znephf Qraxre
__kkk__ naq __ekkk__ if bcrengvba fybgf: cnegvpyr dhnaghz fhcrecbfvgvba xvaq bs sha
ClCl vf na rkpvgvat grpuabybtl gung yrgf lbh gb jevgr snfg, cbegnoyr, zhygv-cyngsbez vagrecergref jvgu yrff rssbeg
Nezva: "Cebybt vf n zrff.", PS: "Ab, vg'f irel pbby!", Nezva: "Vfa'g guvf jung V fnvq?"
ClCl vf yvxr nofheq gurngre
jr unir ab nagv-vzcbffvoyr fgvpx gung znxrf fher gung nyy lbhe cebtenzf unyg
clcl vf n enpr orgjrra crbcyr funivat lnxf naq gur havirefr cebqhpvat zber orneqrq lnxf. Fb sne, gur havirefr vf jvaavat
Nyy ceboyrzf va pbzchgre fpvrapr pna or fbyirq ol nabgure yriry bs vaqverpgvba. --Ohgyre Ynzcfba
jr ner zbivat gbjneqf n ernyyl cngpu-serr nffrzoyre jbeyq (nezva)
<nevtngb> svwny: V'z fher gurer vf gbaf bs hafcrpvsvrq pbagrkg vasbezngvba gung V fubhyq vqrnyyl nyfb or njner bs
<pnzv> V yvxr jbexva jvgu clcl, vg'f yvxr fcrnxvat puvarfr
<nevtngb> lrf ohg gurer vf abg zhpu frafr vs V rkcynva nyy nobhg gbqnl'f terngrfg vqrn vs gbzbeebj vg'f pbzcyrgryl bhgqngrq
<psobym> gur wvg'f fcrrq vf zrnfherq va zo ugzy/frp naq gur qrirybczrag fcrrq vf zrnfherq va oenapurf/qnl
<psobym> gur wvg'f fcrrq vf zrnfherq va bar bire zo ugzy/frp naq gur qrirybczrag fcrrq vf zrnfherq va oenapurf/qnl
gur mra nggvghqr gb cebtenzzvat: erqhpvat gur bbcfrf va lbhe yvsr
clcl vf gur ahpyrne shfvba bs cebtenzzvat ynathntr vzcyrzragngvba (crqebavf)
Gur rkgen oynax yvarf gung clcl cevagf haqre jvaqbjf pbzr sebz qvfghgvyf gung qbrf abg svaq Ivfhny Fghqvb 6
ClCl 1.1.0orgn eryrnfrq: uggc://pbqrfcrnx.arg/clcl/qvfg/clcl/qbp/eryrnfr-1.1.0.ugzy
"gurer fubhyq or bar naq bayl bar boivbhf jnl gb qb vg". ClCl inevnag: "gurer pna or A unys-ohttl jnlf gb qb vg"
1.1 svany eryrnfrq: uggc://pbqrfcrnx.arg/clcl/qvfg/clcl/qbp/eryrnfr-1.1.0.ugzy
<svwny> nzq64 naq ccp ner bayl ninvynoyr va ragrecevfr irefvba
Vf gurer n clcl gvzr? - vs lbh pna srry vg (?) gura gurer vf
<nevtngb> ab, abezny jbex vf fhpu zhpu yrff gvevat guna inpngvbaf
<nevtngb> ab, abezny jbex vf fb zhpu yrff gvevat guna inpngvbaf
-SVEFG gurl vtaber lbh, gura gurl ynhtu ng lbh, gura gurl svtug lbh, gura lbh jva.-
vg'f Fhaqnl, znlor
vg'f Fhaqnl, ntnva
"3 + 3 = 8" - Nagb va gur WVG gnyx
RPBBC vf unccravat
RPBBC vf svavfurq
cflpb rngf bar oenva cre vapu bs cebterff
"Fbzrjurer vafvqr gur ynetr yhzorevat oybo bs ClCl gurer vf na ryrtnag pber gelvat gb trg bhg." - psobym
<nevtngb> gur NV fgngr vf vaqrrq pybfr
gur yytencu onpxraq vf n PCH gbb
jung ner n srj snyfr cbfvgvirf orgjrra sevraqf
abg vaperqvoyl ryrtnag, ohg pbhyq jbex
Jura lbhe unzzre vf P++, rirelguvat ortvaf gb ybbx yvxr n guhzo.
Gurersber, fcrpvsvp vasbezngvba, V jnf va na vqrny pbagrkg, V unq gb ernyvmr gur snvgu
ClCl qrirybczrag: gur neg bs jnvgvat
ubj gb pbafgehpg gur oynpxubyr vagrecergre: jr erhfr gur genpvat bar, nqq ybgf bs vsf naq cenl
clcl vf zber fgnoyr guna qrovna
gur jbeyq qbrfa'g jnag hf gb xabj
guvatf jbexrq avpryl gvyy gbqnl whfg ol punapr
enaqbz ohtf va enaqbz (abg n shaal wbxr)
ab enaqbz ohtf va enaqbz, nsgre nyy
vg'f ornhgvshy: irel erpgnathyne naq lryybj
V jnag n terra gevnathyne lryybj cbal
Vf vg n pnpghf oht be ceboyrz jvgu zl jne?
vg'f qhpg gncr nyy gur jnl qbja ohg abg gur jnl hc
"ribyhgrq" = havba bs "ribyirq" naq "pbaibyhgrq"
vg'f abafrafr nyy gur jnl qbja, naq nyfb nyy gur jnl hc
vg'f abg pbzcyrgryl fnar, ohg gung unf arire fgbccrq hf
gur shgher unf whfg ortha
jung jr npuvrirq gbqnl: jr qvfphffrq gur cbalarff bs gvzr-znpuvarf
Gur gvzr qrpernfrf!
"Jul qb jr raq hc va n aba pbzzba pnfr va gur pbzzba pnfr?" (svwny)
"nu, whfg va gvzr qbphzragngvba" (__nc__)
ClCl vf abg n erny IZ: ab frtsnhyg unaqyref gb qb gur ener pnfrf
lbh pna'g unir obgu pbairavrapr naq fcrrq
fyvccref urvtug pna or zrnfherq va k86 ertvfgref
clcl vf n enpr orgjrra gur vaqhfgel gelvat gb ohvyq znpuvarf jvgu zber naq zber erfbheprf, naq gur clcl qrirybcref gelvat gb rng nyy bs gurz. Fb sne, gur jvaare vf fgvyy hapyrne
"znl pbagnva ahgf naq/be lbhat cbvagref"
vg'f nyy irel fvzcyr, yvxr gur ubyvqnlf
unccl ClCl'f lrne 2010!
fnzhryr fnlf gung jr ybfg n enmbe. fb jr pna'g funir lnxf
"yrg'f abg or bofpher, hayrff jr ernyyl arrq gb"
<nevtngb> (abg guernq-fnsr, ohg jryy, abguvat vf)
clcl unf znal ceboyrzf, ohg rnpu bar unf znal fbyhgvbaf
whfg nabgure vgrz (1.333...) ba bhe erny-ahzorerq gbqb yvfg
ClCl vf Fuveg Bevtnzv erfrnepu
<svwny> nafjrevat n dhrfgvba: "ab -- sbe ng yrnfg bar cbffvoyr vagrecergngvba bs lbhe fragrapr"
eryrnfr 1.2 hcpbzvat
ClCl 1.2 eryrnfrq - uggc://clcl.bet/
AB IPF QVFPHFFVBAF
EClguba vf n svar pnzry unve oehfu
ClCl vf n npghnyyl n ivfhnyvmngvba cebwrpg, jr whfg ohvyq vagrecergref gb unir vagrerfgvat qngn gb ivfhnyvmr
clcl vf yvxr fnhfntrf
naq abj sbe fbzrguvat pbzcyrgryl qvssrerag
n 10gu bs sberire vf 1u45
pbeerpg pbqr qbrfag arrq nal grfgf <qhpx>
cbfgfgehpghenyvfz rgp.
clcl UVG trarengbe
gur arj clcl fcbeg vf gb cnff clcl ohtf nf pclguba ohtf
jr unir zhpu zber vagrecergref guna hfref
ClCl 1.3 njnvgvat eryrnfr
ClCl 1.3 eryrnfrq
vg frrzf gb zr gung bapr lbh frggyr ba na rkrphgvba / bowrpg zbqry naq / be olgrpbqr sbezng, lbh'ir nyernql qrpvqrq jung ynathntrf (jurer gur 'f' frrzf fhcresyhbhf) fhccbeg vf tbvat gb or svefg pynff sbe
"Nyy ceboyrzf va ClCl pna or fbyirq ol nabgure yriry bs vagrecergngvba"
ClCl 1.3 eryrnfrq (jvaqbjf ovanevrf vapyhqrq)
jul qvq lbh thlf unir gb znxr gur ohvygva sbeghar zber vagrerfgvat guna npghny jbex? v whfg pngpurq zlfrys erfgnegvat clcl 20 gvzrf
"jr hfrq gb unir n zrff jvgu na bofpher vagresnpr, abj jr unir zrff urer naq bofpher vagresnpr gurer. cebterff" crqebavf ba n clcl fcevag
"phcf bs pbssrr ner yvxr nanybtvrf va gung V'z znxvat bar evtug abj"
"vg'f nyjnlf hc gb hf, va n jnl be gur bgure"
ClCl vf infg, naq pbagnvaf zhygvghqrf
qravny vf eneryl n tbbq qrohttvat grpuavdhr
"Yrg'f tb." - "Jr pna'g" - "Jul abg?" - "Jr'er jnvgvat sbe n Genafyngvba." - (qrfcnvevatyl) "Nu!"
'gung'f qrsvavgryl n pnfr bs "hu????"'
va gurbel gurer vf gur Ybbc, va cenpgvpr gurer ner oevqtrf
gur uneqqevir - pbafgnag qngn cvytevzntr
ClCl vf n gbby gb xrrc bgurejvfr qnatrebhf zvaqf fnsryl bpphcvrq.
jr ner n trareny senzrjbex ohvyg ba pbafvfgrag nccyvpngvba bs nqubp-arff
gur jnl gb nibvq n jbexnebhaq vf gb vagebqhpr n fgebatre jbexnebhaq fbzrjurer ryfr
pnyyvat gur genafyngvba gbby punva n 'fpevcg' vf xvaq bs bssrafvir
ehaavat clcl-p genafyngr.cl vf n ovg yvxr jngpuvat n guevyyre zbivr, vg pbhyq pbafhzr nyy gur zrzbel ng nal gvzr
ehaavat clcl-p genafyngr.cl vf n ovg yvxr jngpuvat n guevyyre zbivr, vg pbhyq qvr ng nal gvzr orpnhfr bs gur 32-ovg 4TO yvzvg bs ENZ
Qh jvefg rora tranh qnf reervpura, jbena xrvare tynhog
vs fjvgmreynaq jrer jurer terrpr vf (ba vfynaqf) jbhyq gurl nyy or pbaarpgrq ol oevqtrf?
genafyngvat clcl jvgu pclguba vf fbbbbbb fybj
ClCl 1.4 eryrnfrq!
Jr ner abg urebrf, whfg irel cngvrag.
QBAR zrnaf vg'f qbar
jul gurer vf ab "ClCl 1.4 eryrnfrq" va gbcvp nal zber?
fabj! fabj!
svanyyl, zrephevny zvtengvba vf unccravat!
Gur zvtengvba gb zrephevny vf pbzcyrgrq! uggc://ovgohpxrg.bet/clcl/clcl
fabj! fabj! (gre)
unccl arj lrne
naq anaanaw gb lbh nf jryy
Frrvat nf gur ynjf bs culfvpf ner ntnvafg lbh, lbh unir gb pnershyyl pbafvqre lbhe fpbcr fb gung lbhe tbnyf ner ernfbanoyr.
nf hfhny va clcl, gur fbyhgvba nccrnef pbzcyrgryl qvfcebcbegvbangr gb gur ceboyrz naq vafgrnq jr'yy tb sbe n pbzcyrgryl qvssrerag fvzcyre nccebnpu gb gur bevtvany ceboyrz
fabj, fabj!
va clcl lbh ner nyjnlf ng gur jebat yriry, va bar jnl be gur bgure
jryy, vg'f jebat ohg abg fb "irel jebat" nf vg ybbxrq
<svwny> V ybir clcl
ynmvarff vzcngvrapr naq uhoevf
fabj, fabj
EClguba: guvatf lbh jbhyqa'g qb va Clguba, naq pna'g qb va P.
vg vf gur rkcrpgrq orunivbe, rkprcg jura lbh qba'g rkcrpg vg
erqrsvavat lryybj frrzf yvxr n orggre vqrn
"gung'f ubjrire whfg ratvarrevat" (svwny)
"[vg] whfg fubjf ntnva gung eclguba vf bofpher" (psobym)
"naljnl, clguba vf n infg ynathntr" (svwny)
bhg-bs-yvr-thneqf
"gurer ner qnlf ba juvpu lbh ybbx nebhaq naq abguvat fubhyq unir rire jbexrq" (svwny)
clcl vf n orggre xvaq bs sbbyvfuarff - ynp
ehaavat grfgf vf rffragvny sbe qrirybcvat clcl -- hu? qvq V oernx gur grfg? (svwny)
V'ir tbg guvf sybbe jnk gung'f nyfb n TERNG qrffreg gbccvat!!
rknexha: "gur cneg gung V gubhtug jnf tbvat gb or uneq jnf gevivny, fb abj V whfg unir guvf cneg gung V qvqa'g rira guvax bs gung vf uneq"
V fhccbfr jr pna yvir jvgu gur bofphevgl, nf ybat nf gurer vf n pbzzrag znxvat vg yvtugre
V nz n ovt oryvrire va ernfbaf. ohg gur nccnerag xvaq ner zl snibevgr.
clcl: trg n WVG sbe serr (jryy gur svefg qnl lbh jba'g znantr naq vg jvyy or irel sehfgengvat)
<Nyrk_Tnlabe> thgjbegu: bu, jr fubhyq znxr gur WVG zntvpnyyl orggre, jvgu qrpbengbef naq fghss
vg'f n pbzcyrgr unpx, ohg n irel zvavzny bar (nevtngb)
svefg gurl ynhtu ng lbh, gura gurl vtaber lbh, gura gurl svtug lbh, gura lbh jva
ClCl vf snzvyl sevraqyl
jr yvxr pbzcynvagf
gbqnl jr'er snfgre guna lrfgreqnl (hfhnyyl)
ClCl naq PClguba: gurl ner zbegny rarzvrf vagrag ba xvyyvat rnpu bgure
nethnoyl, rirelguvat vf n avpur
clcl unf ynlref yvxr bavbaf: crryvat gurz onpx jvyy znxr lbh pel
EClguba zntvpnyyl znxrf lbh evpu naq snzbhf (fnlf fb ba gur gva)
Vf evtbobg nebhaq jura gur havirefr prnfrf gb rkvfg?
ClCl vf gbb pbby sbe dhrelfgevatf.
< nevtngb> gura jung bpphef? < svwny> tbbq fghss V oryvrir
ClCl 1.6 eryrnfrq!
<psobym> jurer ner gur grfgf?
uggc://gjvgcvp.pbz/52nr8s
N enaqbz dhbgr
Nyy rkprcgoybpxf frrz fnar.
N cvax tyvggrel ebgngvat ynzoqn
"vg'f yvxryl grzcbenel hagvy sberire" nevtb
"""

from string import ascii_uppercase, ascii_lowercase

def rot13(data):
    """ A simple rot-13 encoder since `str.encode('rot13')` was removed from
        Python as of version 3.0.  It rotates both uppercase and lowercase letters individually.
    """
    total = []
    for char in data:
        if char in ascii_uppercase:
            index = (ascii_uppercase.find(char) + 13) % 26
            total.append(ascii_uppercase[index])
        elif char in ascii_lowercase:
            index = (ascii_lowercase.find(char) + 13) % 26
            total.append(ascii_lowercase[index])
        else:
            total.append(char)
    return "".join(total)

def some_topic():
    import time
    lines = __doc__.splitlines()
    return rot13(lines[int(time.time()) % len(lines)])
